WORC.IOparser package — WORC 2.1.1 documentation

# WORC.IOparser package

## Submodules

## WORC.IOparser.config_WORC module

`WORC.IOparser.config_WORC.` `load_config`(config_file_path)

  Parse a WORC configuration file.

  Arguments:
    config_file_path: path to the configuration file to be parsed.
  Returns:
    settings_dict: dictionary containing all parsed settings.

## WORC.IOparser.config_preprocessing module

`WORC.IOparser.config_preprocessing.` `load_config`(config_file_path)

  Parse a WORC configuration file.

  Arguments:
    config_file_path: path to the configuration file to be parsed.
  Returns:
    settings_dict: dictionary containing all parsed settings.

## WORC.IOparser.config_segmentix module

`WORC.IOparser.config_segmentix.` `load_config`(config_file_path)

  Parse a segmentix configuration file.

  Arguments:
    config_file_path: path to the configuration file to be parsed.
  Returns:
    settings_dict: dictionary containing all parsed settings.

## Module contents